package com.ruoyi.invest.service;

import com.ruoyi.invest.domain.TProjectContacts;

import java.util.List;

/**
 * 项目联系人Service接口
 * 
 * @author ruoyi
 * @date 2024-02-22
 */
public interface ITProjectContactsService 
{
    /**
     * 查询项目联系人
     * 
     * @param id 项目联系人主键
     * @return 项目联系人
     */
    public TProjectContacts selectTProjectContactsById(String id);

    /**
     * 查询项目联系人列表
     * 
     * @param tProjectContacts 项目联系人
     * @return 项目联系人集合
     */
    public List<TProjectContacts> selectTProjectContactsList(TProjectContacts tProjectContacts);

    /**
     * 新增项目联系人
     * 
     * @param tProjectContacts 项目联系人
     * @return 结果
     */
    public int insertTProjectContacts(TProjectContacts tProjectContacts);

    /**
     * 修改项目联系人
     * 
     * @param tProjectContacts 项目联系人
     * @return 结果
     */
    public int updateTProjectContacts(TProjectContacts tProjectContacts);

    /**
     * 批量删除项目联系人
     * 
     * @param ids 需要删除的项目联系人主键集合
     * @return 结果
     */
    public int deleteTProjectContactsByIds(String[] ids);

    /**
     * 删除项目联系人信息
     * 
     * @param id 项目联系人主键
     * @return 结果
     */
    public int deleteTProjectContactsById(String id);

    /**
     * 批量删除项目联系人(修改del_flag状态)
     *
     * @param ids 需要删除的项目联系人主键集合
     * @return 结果
     */
    public int updateTProjectContactsByIds(String[] ids);
}
